#[repr(transparent)]pub struct Member {
inner: TypedObjectRef<Member, <Member as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A User in the context of a given room.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Member, <Member as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Member
impl Member
Sourcepub fn power_level_i64(&self) -> <PhantomData<i64> as Property>::Value
pub fn power_level_i64(&self) -> <PhantomData<i64> as Property>::Value
The power level of the member, as an i64.
Should only be used for sorting.
i64::MAX is used to represent an infinite power level, since it
cannot be reached with the Matrix specification.
Sourcepub fn membership(&self) -> <Cell<Membership> as Property>::Value
pub fn membership(&self) -> <Cell<Membership> as Property>::Value
This membership state of the member.
Sourcepub fn latest_activity(&self) -> <Cell<u64> as Property>::Value
pub fn latest_activity(&self) -> <Cell<u64> as Property>::Value
The timestamp of the latest activity of this member.
Sourcepub fn set_latest_activity<'a>(
&self,
value: impl Borrow<<<Cell<u64> as Property>::Value as HasParamSpec>::SetValue>,
)
pub fn set_latest_activity<'a>( &self, value: impl Borrow<<<Cell<u64> as Property>::Value as HasParamSpec>::SetValue>, )
The timestamp of the latest activity of this member.
Sourcepub fn connect_room_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_room_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the room property
Sourcepub fn connect_power_level_i64_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_power_level_i64_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the power-level-i64 property
Sourcepub fn connect_role_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_role_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the role property
Sourcepub fn connect_membership_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_membership_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the membership property
Sourcepub fn connect_latest_activity_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_latest_activity_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the latest-activity property
Sourcepub fn notify_room(&self)
pub fn notify_room(&self)
Notify listeners of a change in the room property
Sourcepub fn notify_power_level_i64(&self)
pub fn notify_power_level_i64(&self)
Notify listeners of a change in the power-level-i64 property
Sourcepub fn notify_role(&self)
pub fn notify_role(&self)
Notify listeners of a change in the role property
Sourcepub fn notify_membership(&self)
pub fn notify_membership(&self)
Notify listeners of a change in the membership property
Sourcepub fn notify_latest_activity(&self)
pub fn notify_latest_activity(&self)
Notify listeners of a change in the latest-activity property
Sourceimpl Member
impl Member
pub fn new(room: &Room, user_id: OwnedUserId) -> Self
Sourcepub(crate) fn power_level(&self) -> UserPowerLevel
pub(crate) fn power_level(&self) -> UserPowerLevel
The power level of the member.
Sourcepub(super) fn set_power_level(&self, power_level: UserPowerLevel)
pub(super) fn set_power_level(&self, power_level: UserPowerLevel)
Set the power level of the member.
Sourcepub(crate) fn update_from_room_member(&self, member: &RoomMember)
pub(crate) fn update_from_room_member(&self, member: &RoomMember)
Update this member with the data from the given SDK’s member.
async fn update_inner(&self)
Sourcepub(crate) fn redactable_events(&self) -> Vec<OwnedEventId>
pub(crate) fn redactable_events(&self) -> Vec<OwnedEventId>
The IDs of the events sent by this member that can be redacted.
Sourcepub(crate) fn can_notify_room(&self) -> bool
pub(crate) fn can_notify_room(&self) -> bool
Whether this room member can notify the whole room.
Sourcepub(crate) fn search_string(&self) -> String
pub(crate) fn search_string(&self) -> String
The string to use to search for this member.
Sourcepub(crate) fn connect_power_level_changed<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub(crate) fn connect_power_level_changed<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when the power level of the member changed.